@@ -11,4 +11,6 @@ from .kendrick_mass_defect import kendrick_mass_defect
 from .filter_spectral_interference import filter_spectral_interference
 from .read_corems import read_corems
 from .msTuple import msTuple
-from .msTupleDict import msTupleDict
\ No newline at end of file
+from .msTupleDict import msTupleDict
+from .average_mstuple import average_mstuple
+from .read_csv import read_csv
\ No newline at end of file
